cd ~/Dropbox/Columbia/Research/Bangladesh/Bangladesh_Final/

clear
set more off

//Collapse baseline data 

//Count household members 

cd Data/Baseline

use q12_clean.dta, clear

//Replace missing values in q12a

gen record = 1
by id (q12a q12b), sort: gen q12afill = sum(record)
tostring q12afill, replace
replace q12a = q12afill if q12a == "."
destring q12a, replace
sort upa vill id q12a

preserve

//Note: a couple of inconsistencies in household number data, looks like there are some missing records for large households

//Count number of records for each household

collapse (count) q12a, by(id)
rename q12a q12a_N
save temp, replace

//Count number of males in each household (note 88 records with missing values for gender in q12_clean)

restore, preserve
keep if q12e == "1"
collapse (count) q12a, by(id)
rename q12a q12a_N_m
merge id using temp, sort
drop _merge 
save temp, replace

//Count number of females in each household (note 88 missing values for gender in q12_clean)

restore, preserve
keep if q12e == "2"
collapse (count) q12a, by(id)
rename q12a q12a_N_f
merge id using temp, sort
drop _merge 
save temp, replace

//Count number of individuals age 5 and below (note 10 missing values for age)

restore, preserve
replace q12f = "0.5" if q12f == "1/2"
destring q12f, replace
keep if q12f <= 5
collapse (count) q12a, by(id)
rename q12a q12a_N_u5
merge id using temp, sort
drop _merge 
save temp, replace

//Count number of individuals age 15 and below

restore
replace q12f = "0.5" if q12f == "1/2"
destring q12f, replace
keep if q12f <= 15
collapse (count) q12a, by(id)
rename q12a q12a_N_u15
merge id using temp, sort
drop _merge 
save temp, replace

//Get household head data

use q12_clean.dta, clear

//Replace missing value in q12c

replace q12c = "1" if id == "170600082078" & q12a == "01"

//Get household head data only

keep if q12c == "1"

//Drop records with evidently wrong values with missing values (i.e. where number of household heads > 1; correcting by cross reference to q12d)

duplicates tag id, gen(dups)
drop if dups > 0 & q12d == "NA"

//If two household heads listed, assume male household head take precedence

drop if dups > 0 & q12e == "2"

//In three cases, two male household heads are listed.  Drop data for member who has been in village fewer years, or where equal, younger member.  

drop if dups > 0 & q12a != "01"

drop dups 

//Rename and drop variables 

foreach var of varlist q12* {
	rename `var' `var'_hh
}	

drop q12a_hh-q12c_hh 

//Merge with hh_size data

merge id using temp, sort
drop _merge 
save temp, replace

//Get spouse data

use q12_clean.dta, clear

//Replace missing value in q12c

replace q12c = "2" if id == "170600082078" & q12a == "02"

//Get spouse data only

keep if q12c == "2"

//Cross ref with q12d to drop incorrectly labelled duplicate spouses 

duplicates tag id, gen(dups)
drop if dups > 0 & q12d == "NA"

//Eleven households have two females plausibly listed as polygamous wives.  In these cases, consider only the first listed.  

drop if dups > 0 & q12a != "02"

drop dups

//Rename and drop variables 

foreach var of varlist q12* {
	rename `var' `var'_sp
}	

drop q12a_sp-q12c_sp 

//Merge with hh_size and hh_head data

merge id using temp, sort
drop _merge 
drop hh vill upa

save temp, replace

use q12_clean.dta, clear

//Generate indicator for whether or not anyone in the household suffers from arsenic poisoning

destring q12l, replace ignore(DK)
gen arsenic = .
replace arsenic = 0 if q12l == 2
replace arsenic = 1 if q12l == 1 | q12l == 3

collapse (max) arsenic, by(id)

//Merge with hh_size and hh_head data

merge id using temp, sort
drop _merge 

save temp, replace

//Get data on water sources

use q23_clean, clear

//Get data on principal water sources

destring q23e, replace ignore(NA)

//Note: 93 entries list NA inappriately.  This command will treat these entries as missing. However, it seems fairly reasonable to assume that NA corresponds to not used for drinking water.   

by id (q23a), sort: egen q23emax = max(q23e)
keep if q23e == q23emax

//7 households list two water sources as being used 50:50.  38 households list two water sources as being used both at 100%.  In both cases, store the first listed response as the principal water source and store the remaining data as alternate water source.  23 households list two (or in one case 3) water sources as zero drinking water use and no sources as > 0.  

duplicates tag id, gen(dups)
destring q23a, replace
preserve
drop if dups > 0 & q23a > 1

//Rename and drop variables 

foreach var of varlist q23* {
	rename `var' `var'_pw
}	

drop q23a_pw q23emax_pw dups

//Merge with rest of data 

merge id using temp, sort
drop _merge 
drop hh vill upa

save temp, replace

//Get alternative well source data

restore 
keep if dups > 0 & q23a > 1

//Note one hh names three wells ALL with zero drinking water use so I drop the third entry

drop if id == "050300056032" & q23a == 3

//Rename and drop variables 

foreach var of varlist q23* {
	rename `var' `var'_pw_alt
}	

drop q23a_pw_alt q23emax_pw_alt dups

//Merge with rest of data 

merge id using temp, sort
drop _merge 
save temp, replace

//Get first-listed well source data

use q23_clean, clear
destring q23a, replace
keep if q23a == 1

//Rename and drop variables 

foreach var of varlist q23* {
	rename `var' `var'_first
}	

drop q23a_first

//Merge with rest of data 

merge id using temp, sort
drop _merge 
save temp, replace

//Get social networks data (count network connections)

//Collapse baseline data 

use q42_clean.dta, clear

//Generate indicator for whether the connection is to a leader/political officer

destring q42k, ignore(DKNRA) gen(q42k_n)

gen leader_connection = .
replace leader_connection = 0 if q42k_n == 2
replace leader_connection = 1 if q42k_n == 1

//Generate indicator for whether the connection is to a leader/political officer by kinship

destring q42d, ignore(DKNRA) gen(q42d_n)

gen kinship = .
replace kinship = 0 if q42d_n > 1 & q42d_n != . 
replace kinship = 1 if q42d_n == 1

gen leader_conn_kinship = leader_connection * kinship

//Collapse data

replace q42b = "03" if q42b == "00"
destring q42b, replace ignore(NRA)

collapse (count) connections = q42b (sum) leader_connections = leader_connection leader_conn_kinships = leader_conn_kinship, by(id)

//Merge with rest of data 

merge id using temp, sort
drop _merge 
save temp, replace

//Get assets data

use q69_clean, clear

//Fix missing values for q69a (string incompatability during prior merge)  

drop if q69a == .
tostring q69a, replace force
append using reentry2_q69
destring q69a, replace

//Fix odd values for q69c

replace q69c = subinstr(q69c, "z", "", .)
replace q69c = "17500" if q69c == "6000,8000,3500"
replace q69c = subinstr(q69c, ",", "", .)
destring q69c, replace ignore(DKRAS)

//This drops one entry that says SS - needs double checking.  

//Correct inconsistencies in data entry 

destring q69b, generate(q69b_num) force
replace q69c = q69b_num if q69a > 2.29 & q69a < 2.31
gen q69cfill = q69c + q69c[_n-1]

replace q69c = q69cfill if q69a > 2.29 & q69a < 2.31
drop if q69a > 2.19 & q69a < 2.21
replace q69a = 2 if q69a > 2.29 & q69a < 2.31

drop if q69a == 3 & q69c < 0.01 & q69b_num < 0.01
drop if q69a == 3 & q69c == . & q69b_num < 0.01
drop if q69a == 3 & q69a < 3.1 & q69c == . & q69b_num == .

replace q69c = q69c + q69c[_n+1] if id == "380720017032" & q69a == 2
drop if id == "380720017032" & q69a == 3

replace q69c = q69c[_n+1] if id == "120720073078" & q69a == 2
drop if id == "120720073078" & q69a == 3

//22 households have the wrong number of entries

//Get land value

preserve

keep if q69a == 1
keep id q69c
rename q69c q69c_land

merge id using temp, sort
drop _merge 
save temp, replace

//Get house value

restore, preserve

keep if q69a == 2
keep id q69c
rename q69c q69c_house

merge id using temp, sort
drop _merge 
save temp, replace

//Get non-land value

restore

keep if q69a > 3
collapse (sum) q69c, by(id)
rename q69c q69c_nonland

merge id using temp, sort
drop _merge 

//Merge with all data

merge id using main_clean, sort
drop _merge

aorder q*
order id
drop hh vill upa
sort q5b q3b q1

replace id = "0" + id + "P"

cd ..

save baseline, replace

//Collapse and merge followup data

cd Followup_additional

//Merge main followup datafiles

//Get followup data from additional households.  

//Update additional manganese households with resurvey data

use main_additional_m_clean, clear
drop v2*

//Drop variables that were resurveyed later

rename q2 q2_orig
renpfix q8_ q8_orig_
rename q12 q12_orig
drop q13-q18 q20-q23_b q25-q75 q90 q94 q99-q102_3 q111 q114

//Merge using redo survey data

merge id using main_additional_m_redo, sort
rename q8__mon q8_re_mon
rename q8_day q8_re_day
rename q8_yr q8_re_yr
rename q12 q12_re
rename q477_3 q41_3
rename q32_add q32_re

gen migrated_re = 0
replace migrated_re = 1 if _merge == 1
drop _merge

//Merge with other additional household data

append using main_additional_clean
append using main_additional_added_clean

//Add A to id code 

replace id = id + "A"
gen additional = 1

//Rename variables to match main followup 

renpfix q114 q124
renpfix q113 q123
renpfix q112 q122
renpfix q111 q121
renpfix q110 q120
renpfix q109 q119
renpfix q108 q118
renpfix q107 q117
renpfix q106 q116
renpfix q104 q114
renpfix q103 q113
renpfix q102 q112
renpfix q101 q111
renpfix q100 q110
renpfix q99 q109
renpfix q98 q108
renpfix q97 q107
renpfix q96 q106
renpfix q95 q105
renpfix q94 q104
renpfix q93 q103
renpfix q92 q102
renpfix q91 q101
renpfix q90 q90_add
renpfix q89 q100
renpfix q88 q99
renpfix q87 q98
renpfix q86 q97
renpfix q85 q96
renpfix q84  q84_add
renpfix q83 q83_add
renpfix q82 q82_add
renpfix q81 q81_add
renpfix q80 q80_add
renpfix q79 q79_add
renpfix q78 q78_add
renpfix q77 q77_add
renpfix q76 q76_add

renpfix q26 q26_add
renpfix q27 q27_add
renpfix q28 q26
renpfix q29 q27_
renpfix q31 q29
renpfix q32 q30
renpfix q33 q31
renpfix q34 q32
renpfix q35 q35_add
renpfix q36 q36_add
renpfix q37 q33
renpfix q38 q34
renpfix q39 q35
renpfix q40 q36
renpfix q41 q37
renpfix q42 q38
renpfix q43 q39
renpfix q44 q40
renpfix q45 q41
renpfix q46 q42
renpfix q47 q43
renpfix q48 q44
renpfix q49 q45
renpfix q50 q46
renpfix q51 q47
renpfix q52 q48
renpfix q53 q49
renpfix q54 q50
renpfix q55 q51
renpfix q56 q52
renpfix q57 q53
renpfix q58 q54
renpfix q59 q55
renpfix q60 q56
renpfix q61 q57
renpfix q62 q58
renpfix q63 q59
renpfix q64 q60
renpfix q65 q61
renpfix q66 q62
renpfix q67 q63
renpfix q68 q64
renpfix q69 q65
renpfix q70 q66
renpfix q71 q67
renpfix q72 q68
renpfix q73 q69
renpfix q74 q70
renpfix q75 q71

rename q40 q40_1

cd ../Followup

//Append with followup data from panel households

append using main_followup_final
append using main_followup_m_final
append using main_followup_added_clean

replace additional = 0 if additional != 1
replace id = "0" + id + "P" if additional == 0

drop v2*
drop comments*
drop _merge
renpfix q qf

save temp, replace

//Get subfile data from followup survey

//Get data from additional households

cd ../Followup_additional

use q30_additional_clean, clear
append using q30_additional_m_redo
append using q30_additional_added_clean

replace id = id + "A"
renpfix q30 q28

//Get data from panel households

cd ../Followup

append using q28_followup_final
append using q28_followup_m_final
append using q28_followup_added_clean
replace id = "0" + id + "P" if length(id) < 14

//Get data on first listed water sources

preserve
destring q28a, replace ignore(NA)
keep if q28a == 1

//Rename and drop variables 

renpfix q28 qf28

foreach var of varlist qf28* {
	rename `var' `var'_first
}	

drop qf28a_first 
save temp2, replace

//Get data on principal water sources

restore
destring q28e, replace ignore(NA%)

//Note: 6 entries list NA inappriately.  This command will treat these entries as missing. However, it seems fairly reasonable to assume that NA corresponds to not used for drinking water. There are also 5 missing values.  

by id (q28a), sort: egen q28emax = max(q28e)
keep if q28e == q28emax

//About 40 observations have values of q28emax < 50% 

//In this case there are a lot of households (676) who are using two main sources of drinking water, of which a very large number (prob 661) are using pond water as their second source.  Keep first listed source as the principal source

duplicates tag id, gen(dups)
destring q28a, replace ignore(NA)
preserve
drop if dups > 0 & q28a > 1

//Rename and drop variables 

renpfix q28 qf28

foreach var of varlist qf28* {
	rename `var' `var'_pw
}	

drop qf28a_pw dups
merge id using temp2, sort
drop _merge 

save temp2, replace  

//Get data on alternative water sources

restore 
keep if dups > 0 & q28a > 1

//Rename and drop variables 

renpfix q28 qf28

foreach var of varlist qf28* {
	rename `var' `var'_pw_alt
}

drop qf28a_pw_alt qf28emax_pw_alt dups

//Merge with rest of data 

merge id using temp2, sort
drop _merge
save temp2, replace  

//Get subfile data from followup survey

//Get data from additional households

cd ../Followup_additional

use q105_additional_clean, clear
append using q105_additional_m_clean
destring q105a, replace
save temp3, replace

use q105_additional_added_clean
destring q105c, replace ignore(",")
append using temp3
replace id = id + "A"
renpfix q105 q115
save temp3, replace

cd ../Followup

use q115_followup_final, clear
append using q115_followup_m_final
destring q115a, replace
append using q115_followup_added_clean
replace q115c = "7800" if q115c == "4000/3800"
destring q115c, replace ignore(","".")
replace id =  "0" + id + "P"
append using ../Followup_additional/temp3
save temp3, replace
preserve

//Get land value

keep if q115a == 1
keep id q115c
rename q115c q115c_land

merge 1:1 id using temp2
drop _merge
save temp2, replace

//Get house value

restore, preserve

keep if q115a == 2
keep id q115c
rename q115c q115c_house

merge id using temp2, sort
drop _merge 
save temp2, replace

//Get non-land value

restore

keep if q115a > 2
collapse (sum) q115c, by(id)
rename q115c q115c_nonland

merge id using temp2, sort
drop _merge 

renpfix q115 qf115

//Merge with rest of data 

merge id using temp2, sort
drop _merge
save temp2, replace  


//Merge with baseline data

use ../baseline, clear
renpfix q qb
merge id using temp, sort
rename _merge _mergebf
merge id using temp2, sort
drop _merge

//Housekeeping

aorder q* 
order qb1-qf124
order id 

capture drop v1* 

replace additional = 0 if additional != 1

//Merge with village list data

drop hh vill upa

gen hh = substr(id,1,3)
gen vill = substr(id,4,3)
gen upa = substr(id,11,3)

gen shortid = vill + upa

cd ..

merge shortid using vill_list_final, uniqusing sort
drop vill_quest - followup_additional_hh 
drop _merge

//Merge with outcome data

merge shortid using wells_final, uniqusing sort

//Consolidate migrated and termite indicators

destring migrated, replace
replace migrated = 0 if migrated != 1 & additional != 1 & status != "assigned to treatment"
gen migrated_prob = migrated
replace migrated_prob = 1 if status != "assigned to treatment" & _mergebf == 1 & shortid != "032032"

gen termites = .
replace termites = 0 if additional != 1
replace termites = 1 if _mergebf == 2 & additional == 0 

//More housekeeping

sort upa vill additional hh 

replace qf8_mon = qf8__mon if qf8_mon == ""
drop qf8__mon

save master, replace

//the end
