cd ~/Dropbox/Columbia/Research/Bangladesh/Bangladesh_Final/

clear
set more off

use Data/master, clear

//Process data for analysis

//Destring variables

replace qb23d_pw = "650" if qb23d_pw == "650F"

foreach var in qb12d_hh qb12f_hh qb12f_sp qb12l_hh qb12l_sp qb14a qb14b qb15 qb23d_pw qb23i_pw qb23j_pw qb23k_pw qb41* qb67 qb4b {
	destring `var', ignore(DKNAR) replace
}

//Recode binary variables

//Code gender of hh as 1 for female, 0 for male

gen qb12e_hh_binary = 0 if qb12e_hh == "1"
replace qb12e_hh_binary = 1 if qb12e_hh == "2"

//Code literacy as 1 for literate, 0 for illiterate

gen qb12i_hh_binary = 0 if qb12i_hh == "2"
replace qb12i_hh_binary = 1 if qb12i_hh == "1"

gen qb12i_sp_binary = 0 if qb12i_sp == "2"
replace qb12i_sp_binary = 1 if qb12i_sp == "1"

//Code hh occupation as 1 for farming, 0 for non-farm

gen qb12j_hh_binary = 0 if qb12j_hh != "1" & qb12j_hh != "." & qb12j_hh != "" 
replace qb12j_hh_binary = 1 if qb12j_hh == "1" 

//Code religion as 1 for muslim and 0 for other

gen qb12m_hh_binary = 0 if qb12m_hh != "1" & qb12m_hh != "." & qb12m_hh != "" 
replace qb12m_hh_binary = 1 if qb12m_hh == "1" 

//Arsenic awareness (gives arsenic as reason for unsafe drinking water, before or after probing): code 1 if yes, 0 if no

gen qb16_binary = 1 if qb16_1 == "1" | qb16_1 == "3"
replace qb16_binary = 0 if qb16_1 == "2" | qb16_1 == "4"

//Code type of principal water source as 1 for tubewell, 0 for others (non-improved).  Note no rainwater use as principal source.  

gen qb23b_pw_binary = 1 if qb23b_pw == "1"
replace qb23b_pw_binary = 0 if qb23b_pw != "1" & qb23b_pw != ""

//Code tested for arsenic 0 if no and 1 if yes

gen qb23f_pw_binary = 0 if qb23f_pw == "2"
replace qb23f_pw_binary = 1 if qb23f_pw == "1"

//Code reported safe for arsenic 0 if no and 1 if yes

gen qb23g_pw_binary = 0 if qb23g_pw == "2"
replace qb23g_pw_binary = 1 if qb23g_pw == "1"

//Code confirmed safe for arsenic 0 if no and 1 if yes

gen qb23h_pw_binary = 0 if qb23h_pw == "2" | qb23h_pw == "3"
replace qb23h_pw_binary = 1 if qb23h_pw == "1"

//Code ownership of well 1 if household owns well, 0 if not

gen qb23k_pw_binary = 1 if qb23k_pw == 1
replace qb23k_pw_binary = 0 if qb23k_pw != 1 & qb23k_pw != .

//Code previously changed well 1 if yes, 0 if no

gen qb25_binary = 0 if qb25 == "2"
replace qb25_binary = 1 if qb25 == "1"

//Code sanitary latrine 1 if yes, 0 if no

gen qb73_binary = 0 if qb73 == "2"
replace qb73_binary = 1 if qb73 == "1"

//Code electricity 1 if yes, 0 if no

gen qb75_binary = 0 if qb75 == "2"
replace qb75_binary = 1 if qb75 == "1"

//Other adjustments

//Sum total days lost to illness (removing outlier value)

replace qb14a = . if qb14a == 2000
gen qb14 = qb14a + qb14b

//Drop depth variable if water source is not tubewell

gen qb23d_pw_clean = qb23d_pw if qb23b_pw_binary == 1

//Generate Gopalganj indicator

gen gopalganj = 0
replace gopalganj = 1 if upa == "032"

//Generate South Matlab indicator

gen smatlab = 0
replace smatlab = 1 if (union_no == "0025" | union_no == "0034" | union_no == "0043" | union_no == "0082" | union_no == "0090") & upa_no == "078"

//Two villages with no feasible technology were encountered, one was dropped before implementation (and then no follow-up survey was undertaken) while one was only discovered in the process of implementation).  Consider both these villages to be in the pool of treated villages, even though we only have follow-up data for one of these villages.  

replace treated = 1 if NONE == 1

//Sum total number of people spoken to each week

gen qb41 = qb41a + qb41b + qb41c + qb41d + qb41e

//Water sources

quiet destring qb23b* , replace ignore(ADKNR)
quiet destring qf28b* , replace ignore(ADKNR)

label define watersources_b  1 "Tubewell" 2 "Dug well" 3 "Rainwater" 4 "Pond/river" 5 "AIRP" 6 "Other"

label values qb23b* watersources_b

label define watersources_f  1 "Tubewell" 2 "Dug well" 3 "Rainwater" 4 "Pond/river" 5 "AIRP" 6 "PSF" 7 "DSTW" 8 "Other"

label values qf28b* watersources_f

//Season used 

quiet destring qb23c* , replace ignore(ADKNR)

label define season 1 "All" 2 "Dry only" 3 "Rainy only"

label values qb23c* season

//Used before 2007?

quiet destring qf28c*, replace ignore(ADKNR)
replace qf28c_pw = 0 if qf28c_pw == 2
replace qf28c_pw_alt = 0 if qf28c_pw_alt == 2

label define yesno 0 "No" 1 "Yes"
label values qf28c* yesno

//Installed by Columbia?

//Correct miscoding of qf28d_first

replace qf28d_first = "2" if qf28b_first == 4 & qf28d_first == "NA" & status == "study"

quiet destring qf28d*, replace ignore(ADKNR)
replace qf28d_first = 0 if qf28d_first == 2
replace qf28d_pw = 0 if qf28d_pw == 2
replace qf28d_pw_alt = 0 if qf28d_pw_alt == 2
label values qf28d* yesno

//Tested arsenic safe

quiet destring qb23f*, replace ignore(ADKNR)
replace qb23f_pw = 0 if qb23f_pw == 2
replace qb23f_pw_alt = 0 if qb23f_pw_alt == 2
label values qb23f* yesno

//Reported arsenic safe

quiet destring qf28f*, replace ignore(ADKNR)
replace qf28f_pw = 0 if qf28f_pw == 2
replace qf28f_pw_alt = 0 if qf28f_pw_alt == 2
label values qf28f* yesno

quiet destring qb23g*, replace ignore(ADKNR)
replace qb23g_pw = 0 if qb23g_pw == 2
replace qb23g_pw_alt = 0 if qb23g_pw_alt == 2
label values qb23g* yesno

//Verified arsenic safe

quiet destring qf28g*, replace ignore(ADKNR)
label define verified 1 "Green" 2 "Red" 3 "Not marked"
label values qf28g* verified

quiet destring qb23h*, replace ignore(ADKNR)
label values qb23h* verified

//Time to walk to source?

quiet destring qf28h* qb23i*, replace ignore(ADKNR)

//Time to wait at source 

quiet destring qf28i* qb23j*, replace ignore(ADKNR)

//Owner of source

quiet destring qf28j* qb23k*, replace ignore(ADKNR)
label define sourceowner 1 "Respondent hh" 2 "Relative w/in bari" 3 "Relative outside bari" 4 "Neighbour" 5 "Lender, employer, landowner, shopkeeper" 6 "Communal" 7 "Other"
label values qf28j* qb23k* sourceowner

//Generate variable "reports using safe drinking water"

//Baseline

gen rsw_b = . 

//Replace rsw with 1 if using a safe source (i.e. rainwater) and does not report it unsafe, or with 0 if using a safe source and reports it unsafe

replace rsw_b = 1 if qb23b_first == 3 & qb23g_first != 0
replace rsw_b = 0 if qb23b_first == 3 & qb23g_first == 0

//Replace rsw with 1 if using a tubewell and reports it safe, or 0 if using a tubewell and reports it unsafe or doesn't know.  

replace rsw_b = 1 if qb23b_first == 1 & qb23g_first == 1 
replace rsw_b = 0 if qb23b_first == 1 & qb23g_first != 1

//Replace rsw with 1 if using 'other' and reports it safe, or 0 if using another source reported unsafe or doesn't know

replace rsw_b = 1 if qb23b_first == 6 & qb23g_first == 1 
replace rsw_b = 0 if qb23b_first == 6 & qb23g_first != 1

//Replace rsw with 0 if using an unsafe source i.e. a dug well or surface water

replace rsw_b = 0 if (qb23b_first == 2 |qb23b_first == 4 |qb23b_first == 5)

//Followup

gen rsw_f = .

//Replace rsw with 1 if using a safe source (e.g. AIRP) and does not report it unsafe, or with 0 if using a safe source and reports it unsafe

replace rsw_f = 1 if (qf28b_first == 3 |qf28b_first == 5 | qf28b_first == 6 | qf28b_first == 7) & qf28f_first != 0
replace rsw_f = 0 if (qf28b_first == 3 |qf28b_first == 5 | qf28b_first == 6 | qf28b_first == 7) & qf28f_first == 0

//Replace rsw with 1 if using a tubewell and reports it safe, or 0 if using a tubewell and reports it unsafe or doesn't know.  

replace rsw_f = 1 if qf28b_first == 1 & qf28f_first == 1 
replace rsw_f = 0 if qf28b_first == 1 & qf28f_first != 1

//Replace rsw with 1 if using 'other' and reports it safe, or 0 if using another source reported unsafe or doesn't know

replace rsw_f = 1 if qf28b_first == 8 & qf28f_first == 1 
replace rsw_f = 0 if qf28b_first == 8 & qf28f_first != 1

//Replace rsw with 0 if using an unsafe source i.e. a dug well or surface water

replace rsw_f = 0 if (qf28b_first == 2 |qf28b_first == 4)

//Generate rsw_diff

gen rsw_diff = rsw_f - rsw_b

//Generate variable "use of safe drinking water verified"

//Baseline

gen vsw_b = . 

//Replace vsw with 1 if using a safe source (e.g. AIRP) and verified safe, or with 0 if verified unsafe or not verified. 

replace vsw_b = 1 if qb23b_first == 3 & qb23h_first == 1
replace vsw_b = 0 if qb23b_first == 3 & qb23h_first != 1

//Replace vsw with 1 if using a tubewell which can be verified safe, or 0 if using a tubewell which is found unsafe or can't be verified safe.  

replace vsw_b = 1 if qb23b_first == 1 & qb23h_first == 1 
replace vsw_b = 0 if qb23b_first == 1 & qb23h_first != 1

//Replace vsw with 1 if using 'other' which can be verified safe, or 0 if using another source verified unsafe or unable to be verified.  

replace vsw_b = 1 if qb23b_first == 6 & qb23h_first == 1 
replace vsw_b = 0 if qb23b_first == 6 & qb23h_first != 1

//Replace vsw with 0 if using an unsafe source i.e. a dug well or surface water

replace vsw_b = 0 if (qb23b_first == 2 |qb23b_first == 4 |qb23b_first == 5)

//Followup

gen vsw_f = .

//Replace vsw with 1 if using a safe source (e.g. AIRP) and verified safe, or with 0 if verified unsafe or not verified.  

replace vsw_f = 1 if (qf28b_first == 3 |qf28b_first == 5 | qf28b_first == 6 | qf28b_first == 7) & qf28g_first == 1
replace vsw_f = 0 if (qf28b_first == 3 |qf28b_first == 5 | qf28b_first == 6 | qf28b_first == 7) & qf28g_first != 1

//Replace vsw with 1 if using a tubewell that is verified safe, and with 0 if using a tubewell that is unsafe or not verified.

replace vsw_f = 1 if qf28b_first == 1 & qf28g_first == 1 
replace vsw_f = 0 if qf28b_first == 1 & qf28g_first != 1

//Replace vsw with 1 if using 'other' that is verified safe or 0 if using another source that is unsafe or can't be verified

replace vsw_f = 1 if qf28b_first == 8 & qf28g_first == 1 
replace vsw_f = 0 if qf28b_first == 8 & qf28g_first != 1

//Replace vsw with 0 if using an unsafe source i.e. a dug well or surface water

replace vsw_f = 0 if (qf28b_first == 2 |qf28b_first == 4)

//Generate vsw_diff

gen vsw_diff = vsw_f - vsw_b

//Create variable that combines i) verified safe if verifiable with ii) reported safe if unverifiable at baseline 

gen vrsw_b = .  

//Replace vrsw = 0 if verified unsafe, and 1 if verified safe

replace vrsw_b = 1 if qb23h_first == 1
replace vrsw_b = 0 if qb23h_first == 2

//Else, use rsw_b 

replace vrsw_b = rsw_b if vrsw_b == .

//Create variable that combines i) verified safe if verifiable with ii) reported safe if unverifiable at followup  

gen vrsw_f = .  

//Replace vrsw = 0 if verified unsafe, and 1 if verified safe

replace vrsw_f = 1 if qf28g_first == 1
replace vrsw_f = 0 if qf28g_first == 2

//Else, use rsw_f 

replace vrsw_f = rsw_f if vrsw_f == .

//Generate vrsw_diff

gen vrsw_diff =  vrsw_f - vrsw_b

//Generate "verifiable" variable

gen ver_b = . 
replace ver_b = 0 if qb23h_first > 2 & additional == 0
replace ver_b = 1 if qb23h_first <= 2 & additional == 0

gen ver_f = . 
replace ver_f = 0 if qf28g_first > 2 
replace ver_f = 1 if qf28g_first <= 2 

gen ver_diff = ver_f - ver_b

//Generate total assets variable

gen totalassets = qb69c_house + qb69c_land + qb69c_nonland
 
//Destring number of community associations

destring qb44, replace ignore(DK)

//Destring number of coordinated actions 
 
destring qb46, replace ignore(DK)

//Generate synthetic treatment indicator which restores random assignment in Matlab 

drop _merge
merge shortid using Data/rand, uniqusing sort

//reassign some villages in South Matlab to control

gen reassign = 0 
replace reassign = 1 if rand < 0.4 & ngo == 1 & smatlab == 1
replace reassign = 1 if rand < 0.64 & cp == 1 & smatlab == 1
replace reassign = 1 if rand < 0.35 & td == 1 & smatlab == 1

gen treat_syn = treated 
replace treat_syn = 0 if reassign == 1

//reassign some villages in North Matlab to treatment

replace treat_syn = 1 if gopalganj == 0 & smatlab == 0 & rand < 0.25 & assignedtotreatment == 0

gen control_syn = control
replace control_syn = 1 if treat_syn == 0 & treated == 1

//Generate synthetic model indicators

foreach var in ngo cp td {
	replace `var' = 0 if `var' == .
	gen `var'_syn = `var' * treat_syn
}

replace cp_syn = 1 if gopalganj == 0 & smatlab == 0 & rand < 0.12  & assignedtotreatment == 0
replace ngo_syn = 1 if gopalganj == 0 & smatlab == 0 & rand > 0.12 & rand < 0.20 & assignedtotreatment == 0
replace td_syn = 1 if gopalganj == 0 & smatlab == 0 & rand < 0.20  & rand < 0.25 & assignedtotreatment == 0

//Merge with BAMWSP data

drop _merge
merge m:1 shortid  using Data/BAMWSP_short, keepusing(perc_conta hh_final twoperative as_conta) keep(match master)

replace perc_conta = perc_conta/100

//Randomization checks: treatment versus control

preserve

//Drop villages which were assigned to treatment and not treated.  

drop if status == "assigned to treatment"

//Drop 2 villages where no treatment was feasible, because we do not have follow-up data from one of these villages, and so for consistency we drop them both.  

drop if NONE == 1

//Drop data from additional households (not randomly sampled at follow-up)

drop if additional == 1

//Calculate weights for use in household-level regressions 

gen hh_num = substr(id,1,3) 
destring hh_num, replace

by shortid, sort: egen hhs_b = count(hh_num) if termites == 0
gen pweight_b = 40/hhs_b

//Count number of households in different samples

mat Ns = J(1,5,.)

local j = 2

count 
mat Ns[1,`j'] = r(N)

local j = `j' + 1

count if smatlab == 0
mat Ns[1,`j'] = r(N)

local j = `j' + 1

count
mat Ns[1,`j'] = r(N)

local j = `j' + 1

count
mat Ns[1,`j'] = r(N)

mat Nmodels = J(1,3,.)

local j = 1

count if td == 1 
mat Nmodels[1,`j'] = r(N)

local j = `j' + 1

count if cp == 1
mat Nmodels[1,`j'] = r(N)

local j = `j' + 1

count if ngo == 1
mat Nmodels[1,`j'] = r(N)

//Collapse data to village averages

local varlist = "gopalganj smatlab qb4b installed AIRP_pre AIRP_post DSTW_pre DSTW_post STW_pre STW_post DTW NONE tubewell_pre tubewell_post rsw_b rsw_f rsw_diff ver_b ver_f ver_diff vsw_b vsw_f vsw_diff vrsw_b vrsw_f vrsw_diff qb25_binary arsenic totalassets qb75_binary qb12i_hh_binary qb12m_hh_binary qb12j_hh_binary qb44 qb46 treat_syn control treated ngo cp td hh_final perc_conta twoperative as_conta" 

collapse `varlist', by(shortid) 

//Create matrices to store values for randomization tests.

mat rand_checks = J(45,5,.)
mat rand_checks_pvals = J(45,5,.)

svyset _n

local varlist = "hh_final perc_conta rsw_b qb25_binary arsenic totalassets qb75_binary qb12i_hh_binary qb12m_hh_binary qb12j_hh_binary qb44 qb46"

local i = 0

//Treated vs control

// Test individual outcomes and test simultaneous equality using Hotelling's T tests. Note, the Hotelling's T Tests are not stratified, so will tend to overreject equality by treated and control groups.  

foreach var of varlist `varlist' {

	quiet svy: mean `var', over(treated)
	mat rand_checks[`i'*3 + 1,1] = _b[0] 
	mat rand_checks[`i'*3 + 2,1] = _se[0]
	
	local j = 2
	
	quiet reg `var' treated gopalganj, vce(robust) 
	
	mat rand_checks[`i'*3 + 1,`j'] = _b[treated] 
	mat rand_checks[`i'*3 + 2,`j'] = _se[treated]	
	quiet test treated
	mat rand_checks_pvals[`i'*3 + 1,`j'] = r(p)
	
	local j = `j' + 1
	
	quiet reg `var' treated gopalganj if smatlab == 0, vce(robust)
	
	mat rand_checks[`i'*3 + 1,`j'] = _b[treated] 
	mat rand_checks[`i'*3 + 2,`j'] = _se[treated]
	quiet test treated
	mat rand_checks_pvals[`i'*3 + 1,`j'] = r(p)
	
	local j = `j' + 1
	
	quiet reg `var' treat_syn gopalganj, vce(robust)
	mat rand_checks[`i'*3 + 1,`j'] = _b[treat_syn] 
	mat rand_checks[`i'*3 + 2,`j'] = _se[treat_syn]
	quiet test treat_syn
	mat rand_checks_pvals[`i'*3 + 1,`j'] = r(p)
	
	local j = `j' + 1
	
	quiet ivreg2 `var' (treated = treat_syn) gopalganj, robust ffirst
	mat rand_checks[`i'*3 + 1,`j'] = _b[treated] 
	mat rand_checks[`i'*3 + 2,`j'] = _se[treated]
	quiet test treated
	mat rand_checks_pvals[`i'*3 + 1,`j'] = r(p)
	
	local i = `i' + 1
	
}

local j = 2

hotelling `varlist',  by(treated)
mat rand_checks[`i'*3 + 1,`j'] = r(T2) * (r(N) - r(k) - 1) /((r(N) - 2) * r(k))

local j = `j' + 1

hotelling `varlist' if smatlab == 0,  by(treated)
mat rand_checks[`i'*3 + 1,`j'] = r(T2) * (r(N) - r(k) - 1) /((r(N) - 2) * r(k))

local j = `j' + 1

hotelling `varlist',  by(treat_syn)
mat rand_checks[`i'*3 + 1,`j'] = r(T2) * (r(N) - r(k) - 1) /((r(N) - 2) * r(k))

local j = 2

count 
mat rand_checks[`i'*3 + 2,`j'] = r(N)

local j = `j' + 1

count if smatlab == 0
mat rand_checks[`i'*3 + 2,`j'] = r(N)

local j = `j' + 1

count
mat rand_checks[`i'*3 + 2,`j'] = r(N)

local j = `j' + 1

count
mat rand_checks[`i'*3 + 2,`j'] = r(N)

mat rand_checks[`i'*3 + 3,1] = Ns


svmat rand_checks
outsheet rand_checks* using Output/rand_checks.csv, comma replace
drop rand_checks*

svmat rand_checks_pvals
outsheet rand_checks* using Output/rand_checks_pvals.csv, comma replace
drop rand_checks*

//Randomization checks, by model

mat rand_checks_models = J(48,3,.)
mat rand_checks_models_pvals = J(48,3,.)

svyset _n

local varlist = "gopalganj smatlab hh_final perc_conta AIRP_post rsw_b qb25_binary arsenic totalassets qb75_binary qb12i_hh_binary qb12m_hh_binary qb12j_hh_binary qb44 qb46"

local models = "td cp ngo"

gen model_ind = 1*(td == 1) + 2*(cp == 1) + 3*(ngo == 1)

local i = 0

foreach var of varlist `varlist' {

	quiet svy: mean `var' if treated == 1, over(model_ind)
	forvalues j = 1(1)3 {
		mat rand_checks_models[`i'*3 + 1,`j'] = _b[`j'] 
		mat rand_checks_models[`i'*3 + 2,`j'] = _se[`j']
	}
	local j = 1
	foreach model of varlist `models' {
		quiet reg `var' `model' if treated == 1, vce(robust)
		quiet test `model'
		mat rand_checks_models_pvals[`i'*3 + 1,`j'] = r(p)
		local j = `j' + 1
	}
	local i = `i' + 1
}

local j = 1

hotelling `varlist' if treated == 1,  by(td)
mat rand_checks_models[`i'*3 + 1,`j'] = r(T2) * (r(N) - r(k) - 1) /((r(N) - 2) * r(k))

local j = `j' + 1

hotelling `varlist' if treated == 1,  by(cp)
mat rand_checks_models[`i'*3 + 1,`j'] = r(T2) * (r(N) - r(k) - 1) /((r(N) - 2) * r(k))

local j = `j' + 1

hotelling `varlist' if treated == 1,  by(ngo)
mat rand_checks_models[`i'*3 + 1,`j'] = r(T2) * (r(N) - r(k) - 1) /((r(N) - 2) * r(k))

local j = 1

count if td == 1
mat rand_checks_models[`i'*3 + 2,`j'] = r(N)

local j = `j' + 1

count if cp == 1
mat rand_checks_models[`i'*3 + 2,`j'] = r(N)

local j = `j' + 1

count if ngo == 1
mat rand_checks_models[`i'*3 + 2,`j'] = r(N)


mat rand_checks_models[`i'*3 + 3,1] = Nmodels

svmat rand_checks_models
outsheet rand_checks* using Output/rand_checks_models.csv, comma replace
drop rand_checks*

svmat rand_checks_models_pvals
outsheet rand_checks* using Output/rand_checks_models_pvals.csv, comma replace
drop rand_checks*

//Pairwise Hotelling's T-squared tests (reported in Table notes)

hotelling `varlist' if treated == 1 & cp == 0,  by(ngo) notable
hotelling `varlist' if treated == 1 & td == 0,  by(cp) notable
hotelling `varlist' if treated == 1 & ngo == 0,  by(td) notable

//Create table showing number of wells feasible and constructed in treated and tubewell villages

//Generate "max poss" number

gen max = .
replace max = 3 if DTW == 1
replace max = 3 if STW_pre == 1
replace max = 2 if AIRP_pre == 1
replace max = 2 if DSTW_pre == 1
replace max = 0 if NONE == 1

gen prop = installed/max

local outcomes = "max installed prop"
local groups = "treated tubewell_pre"

mat installed = J(60,6,.)

local i = 1  

foreach outcome of local outcomes {

	foreach group of local groups {

		local k = 1 
		capture reg `outcome' if `group' == 1, vce(robust)
		mat installed[`k', `i'] = _b[_cons]
		mat installed[`k'+1, `i'] = _se[_cons]
		local k = 4
		foreach model in td cp ngo {
			capture reg `outcome' if `group' == 1 & `model' == 1, vce(robust)
			mat installed[`k', `i'] = _b[_cons]
			mat installed[`k'+1, `i'] = _se[_cons]
			local k = `k' + 3
		}
		capture reg `outcome' ngo cp td if `group' == 1, vce(robust) noconstant
		capture test ngo = cp
		mat installed[ `k', `i'] = r(p)
		capture test cp = td
		mat installed[`k'+1, `i'] = r(p)
		capture test td = ngo
		mat installed[`k'+2, `i'] = r(p)
		
		local k = `k' + 3
		
		foreach model in td cp ngo {
			capture reg `outcome' `model' if `group' == 1, vce(robust)
			capture test `model'
			mat installed[`k', `i'] = r(p)
			local k = `k' + 1
		}
		
		capture count if `group' == 1 & `outcome' != .		
		
		mat installed[`k', `i'] = r(N)
		
		local i = `i' + 1

	}
	
}	
	
svmat installed
outsheet installed1-installed6 using Output/installed.csv, comma replace
drop installed1-installed6

//Make table with estimated average treatment effects
 
//Generate matched control group for AIRP villages

logit AIRP_post i.qb4b qb75_binary twoperative as_conta rsw_b ver_b vsw_b qb25_binary arsenic qb12i_hh_binary qb46 if treated == 1 & gopalganj == 1
predict AIRP_pred if gopalganj == 1

//Some unions predict AIRP status perfectly

by qb4b, sort: egen AIRPmean = mean(AIRP_post) if gopalganj == 1 & treated == 1

//Extract unions that predict no AIRP perfectly

gen AIRPmeantemp = AIRPmean
replace AIRPmeantemp = . if AIRPmean > 0
by qb4b gopalganj, sort: egen AIRP_predtemp = min(AIRPmeantemp) if gopalganj == 1 
replace AIRP_pred = AIRP_predtemp if AIRP_pred == .

drop AIRPmeantemp AIRP_predtemp

//Extract unions that predict AIRPs perfectly

gen AIRPmeantemp = AIRPmean
replace AIRPmeantemp = . if AIRPmean < 1
by qb4b gopalganj, sort: egen AIRP_predtemp = min(AIRPmeantemp) if gopalganj == 1 
replace AIRP_pred = AIRP_predtemp if AIRP_pred == .

drop AIRPmeantemp AIRP_predtemp

//Generate AIRP_control group

gen AIRP_control = 0
replace AIRP_control = 1 if AIRP_pred > 0.5 & control == 1 & gopalganj == 1

//Repeat for tubewell villages

logit tubewell_post i.qb4b qb75_binary twoperative as_conta rsw_b ver_b vsw_b qb25_binary arsenic qb12i_hh_binary qb46 if treated == 1 & gopalganj == 1
predict tubewell_pred if gopalganj == 1

//Some unions predict tubewell status perfectly

by qb4b, sort: egen tubewellmean = mean(tubewell_post) if gopalganj == 1 & treated == 1

//Extract unions that predict no tubewell perfectly

gen tubewellmeantemp = tubewellmean
replace tubewellmeantemp = . if tubewellmean > 0
by qb4b gopalganj, sort: egen tubewell_predtemp = min(tubewellmeantemp) if gopalganj == 1 
replace tubewell_pred = tubewell_predtemp if tubewell_pred == .

drop tubewellmeantemp tubewell_predtemp

//Extract unions that predict tubewell perfectly

gen tubewellmeantemp = tubewellmean
replace tubewellmeantemp = . if tubewellmean < 1
by qb4b gopalganj, sort: egen tubewell_predtemp = min(tubewellmeantemp) if gopalganj == 1 
replace tubewell_pred = tubewell_predtemp if tubewell_pred == .

drop tubewellmeantemp tubewell_predtemp

//Generate tubewell_control

gen tubewell_control = 0
replace tubewell_control = 1 if tubewell_pred > 0.5 & control == 1 & gopalganj == 1

//Add Matlab to matched control group for tubewells

replace tubewell_control = 0 if gopalganj == 0 & treated == 1
replace tubewell_control = 1 if gopalganj == 0 & treated == 0

//Replace zeros for matched control group for AIRPS

replace AIRP_control = 0 if AIRP_control == .

//Regressions for baseline, followup and difference table (overall treatment effect)

foreach stub in f diff {

	quiet reg rsw_`stub' treated gopalganj, vce(robust)
	estimates store e`stub'1

	quiet reg rsw_`stub' treated gopalganj if smatlab == 0, vce(robust)
	estimates store e`stub'2

	quiet ivreg2 rsw_`stub' (treated = treat_syn) gopalganj, robust ffirst
	estimates store e`stub'3
	
	quiet reg rsw_`stub' treated gopalganj if tubewell_post == 1 | tubewell_control == 1, vce(robust)
	estimates store e`stub'4

	quiet reg rsw_`stub' treated gopalganj if smatlab == 0 & (tubewell_post == 1 | tubewell_control == 1), vce(robust)
	estimates store e`stub'5

	quiet ivreg2 rsw_`stub' (treated = treat_syn) gopalganj if tubewell_post == 1 | tubewell_control == 1 , robust ffirst
	estimates store e`stub'6

	quiet reg rsw_`stub' treated if AIRP_post == 1 | AIRP_control == 1 , vce(robust)
	estimates store e`stub'7
	
}

//Regression-based Hausman tests for endogeneity

foreach stub in f diff {

	quiet reg treated treat_syn gopalganj if rsw_`stub' != ., vce(robust)
	predict treated_resid, resid
	
	quiet reg rsw_`stub' treated treated_resid gopalganj, vce(robust) 
	
	estimates store e`stub'3_hausman
	
	drop treated_resid
	
	quiet reg treated treat_syn gopalganj if rsw_`stub' != . & (tubewell_post == 1 | tubewell_control == 1), vce(robust)
	predict treated_resid, resid
	
	quiet reg rsw_`stub' treated treated_resid gopalganj if (tubewell_post == 1 | tubewell_control == 1), vce(robust) 
	
	estimates store e`stub'6_hausman
	
	drop treated_resid
	
}


//Populate matrix

mat ests_t = J(36,7,.)
mat ests_t_pvals = J(36,7,.)

local vars = "treated gopalganj"

forvalues i = 1/7 {
	local k = 0 
	foreach stub in f diff{
		estimates restore e`stub'`i'
		local j = 0
		foreach var of local vars {
			capture mat ests_t[`k'*11+`j'*2 + 1,`i'] = _b[`var']
			capture mat ests_t[`k'*11+`j'*2 + 2,`i'] = _se[`var']
			capture test `var'
			capture mat ests_t_pvals[`k'*11+`j'*2 + 1,`i'] = r(p)
			local j = `j' + 1
		}

		capture mat ests_t[`k'*11+`j'*2 + 1,`i'] = _b[_cons]
		capture mat ests_t[`k'*11+`j'*2 + 2,`i'] = _se[_cons]

		capture mat temp = e(first)
		capture mat ests_t[`k'*11+`j'*2 + 4,`i'] = temp[4,1]
		capture matrix drop temp
		
		if `i' == 3 | `i' == 6 {
			estimates store e`stub'`i'
			estimates restore e`stub'`i'_hausman
			
			capture test treated_resid
			capture mat ests_t[`k'*11+`j'*2 + 5,`i'] = r(p)
			
			estimates store e`stub'`i'_hausman
			estimates restore e`stub'`i'		
		}

		capture mat ests_t[`k'*11+`j'*2 + 6,`i'] = e(N)

		estimates store e`stub'`i'
		
		local k = `k' + 1 
	}
}

svmat ests_t
outsheet ests_t* using Output/ests_t.csv, comma replace
drop ests_t*

svmat ests_t_pvals
outsheet ests_t* using Output/ests_t_pvals.csv, comma replace
drop ests_t*

//Compare effects under different models

//Run regressions

foreach stub in f diff {

	quiet reg rsw_`stub' ngo cp td if treated == 1, vce(robust) nocons
	estimates store e`stub'_m1
	
	foreach var in td cp ngo {
		quiet reg rsw_`stub' `var' if treated == 1, vce(robust) 
		estimates store e`stub'_m1_`var'
	}
	
	quiet reg rsw_`stub' ngo cp td if tubewell_post == 1, vce(robust) nocons
	estimates store e`stub'_m2
	
	foreach var in td cp ngo {
		quiet reg rsw_`stub' `var' if tubewell_post == 1, vce(robust) 
		estimates store e`stub'_m2_`var'
	}

	quiet reg rsw_`stub' ngo cp td if AIRP_post == 1, vce(robust) nocons
	estimates store e`stub'_m3
	
	foreach var in td cp ngo {
		quiet reg rsw_`stub' `var' if AIRP_post == 1, vce(robust) 
		estimates store e`stub'_m3_`var'
	}
	
}


//Populate matrix

mat ests_m = J(48,7,.)
mat ests_m_pvals = J(48,7,.)

local vars = "td cp ngo "

local k = 1

forvalues i = 1/3 {
	foreach stub in f diff{
		estimates restore e`stub'_m`i'
		local j = 0
		foreach var of local vars {
			capture mat ests_m[`j'*2 + 1,`k'] = _b[`var']
			capture mat ests_m[`j'*2 + 2,`k'] = _se[`var']
			capture test `var'
			capture mat ests_m_pvals[`j'*2 + 1,`k'] = r(p)
			local j = `j' + 1
		}

		capture mat ests_m[`j'*2 + 1,`k'] = _b[_cons]
		capture mat ests_m[`j'*2 + 2,`k'] = _se[_cons]
	
		capture test ngo = cp
		capture mat ests_m[`j'*2 + 3,`k'] = r(p)
		capture test cp = td
		capture mat ests_m[`j'*2 + 4,`k'] = r(p)
		capture test td = ngo
		capture mat ests_m[`j'*2 + 5,`k'] = r(p)
		
		local l = 6
		
		estimates store e`stub'_m`i'
		
		foreach var of local vars {
			estimates restore e`stub'_m`i'_`var'
			
			capture test `var'
			capture mat ests_m[`j'*2 + `l',`k'] = r(p)
			
			estimates store e`stub'_m`i'_`var'		
			
			local l = `l' + 1
		}	
		
		estimates restore e`stub'_m`i'

		capture mat ests_m[`j'*2 + 9,`k'] = e(N)

		estimates store e`stub'_m`i'
		
		local k = `k' + 1
	}
}

svmat ests_m
outsheet ests_m* using Output/ests_m.csv, comma replace
drop ests_m*

svmat ests_m_pvals
outsheet ests_m* using Output/ests_m_pvals.csv, comma replace
drop ests_m*




save Data/temp, replace
//the end
